==> gtkmm-1.3.10.tar.gz: gtkmm-1.3.10/gdk/gdkmm/cursor.cc <==

extern "C"
{
#include <glib-object.h>
#include <gdk/gdkenumtypes.h>
}

#include <gdkmm/cursor.h>
#include <gdkmm/private/cursor_p.h>

#include <gdk/gdkenumtypes.h>
// -*- c++ -*-
/* $Id: cursor.ccg,v 1.6 2002/04/02 13:23:10 daniel Exp $ */

/*
 *
 * Copyright 1998-1999 The Gtk-- Development Team
 * Copyright 2001      Free Software Foundation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gdk/gdkcursor.h>

namespace Gdk
{

Cursor::Cursor(CursorType cursor_type)
{
  gobject_ = gdk_cursor_new((GdkCursorType) cursor_type);
}

Cursor::Cursor(const Glib::RefPtr<Pixmap>& source, const Glib::RefPtr<Pixmap>& mask,
				       const Color& fg, const Color& bg,
				       int x, int y)
{
  gobject_ = gdk_cursor_new_from_pixmap(source->gobj(), mask->gobj(), 
                                        const_cast<GdkColor*>(fg.gobj()),
				        const_cast<GdkColor*>(bg.gobj()),
                                        x, y);
}


} //namespace Gdk


namespace
{
} // anonymous namespace

// static
GType Glib::Value<Gdk::CursorType>::value_type()
{
  return gdk_cursor_type_get_type();
}


namespace Glib
{

Gdk::Cursor wrap(GdkCursor* object, bool take_copy /* = false */)
{
  return Gdk::Cursor(object, take_copy);
}

} // namespace Glib


namespace Gdk
{


// static
GType Cursor::get_type()
{
  return gdk_cursor_get_type();
}

Cursor::Cursor()
:
  gobject_ (0) // Allows creation of invalid wrapper, e.g. for output arguments to methods.
{}

Cursor::Cursor(const Cursor& src)
:
  gobject_ ((src.gobject_) ? gdk_cursor_ref(src.gobject_) : 0)
{}

Cursor::Cursor(GdkCursor* castitem, bool make_a_copy /* = true */)
{
  // For BoxedType wrappers, make_a_copy is true by default.  The static
  // BoxedType wrappers must always take a copy, thus make_a_copy = true
  // ensures identical behaviour if the default argument is used.

  if(make_a_copy)
  {
    if(castitem)
      gobject_ = gdk_cursor_ref(castitem);
    else
      gobject_ = 0;
  }
  else
  {
    // It was given to us by a function which has already made a copy for us to keep.
    gobject_ = castitem;
  }
}

Cursor& Cursor::operator=(const Cursor& src)
{
  GdkCursor *const new_gobject = (src.gobject_) ? gdk_cursor_ref(src.gobject_) : 0;

  if(gobject_)
    gdk_cursor_unref(gobject_);
  gobject_ = new_gobject;

  return *this;
}

Cursor::~Cursor()
{
  if(gobject_)
    gdk_cursor_unref(gobject_);}


GdkCursor* Cursor::gobj_copy() const
{
  return gdk_cursor_ref(gobject_);
}


} // namespace Gdk

==> gtkmm-1.3.14.tar.gz: gtkmm-1.3.14/gdk/gdkmm/cursor.cc <==

extern "C"
{
#include <glib-object.h>
#include <gdk/gdkenumtypes.h>
}

#include <gdkmm/cursor.h>
#include <gdkmm/private/cursor_p.h>

#include <gdk/gdkenumtypes.h>
// -*- c++ -*-
/* $Id: cursor.ccg,v 1.6 2002/04/02 13:23:10 daniel Exp $ */

/*
 *
 * Copyright 1998-1999 The Gtk-- Development Team
 * Copyright 2001      Free Software Foundation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gdk/gdkcursor.h>

namespace Gdk
{

Cursor::Cursor(CursorType cursor_type)
{
  gobject_ = gdk_cursor_new((GdkCursorType) cursor_type);
}

Cursor::Cursor(const Glib::RefPtr<Pixmap>& source, const Glib::RefPtr<Pixmap>& mask,
				       const Color& fg, const Color& bg,
				       int x, int y)
{
  gobject_ = gdk_cursor_new_from_pixmap(source->gobj(), mask->gobj(), 
                                        const_cast<GdkColor*>(fg.gobj()),
				        const_cast<GdkColor*>(bg.gobj()),
                                        x, y);
}


} //namespace Gdk


namespace
{
} // anonymous namespace

// static
GType Glib::Value<Gdk::CursorType>::value_type()
{
  return gdk_cursor_type_get_type();
}


namespace Glib
{

Gdk::Cursor wrap(GdkCursor* object, bool take_copy)
{
  return Gdk::Cursor(object, take_copy);
}

} // namespace Glib


namespace Gdk
{


// static
GType Cursor::get_type()
{
  return gdk_cursor_get_type();
}

Cursor::Cursor()
:
  gobject_ (0) // Allows creation of invalid wrapper, e.g. for output arguments to methods.
{}

Cursor::Cursor(const Cursor& src)
:
  gobject_ ((src.gobject_) ? gdk_cursor_ref(src.gobject_) : 0)
{}

Cursor::Cursor(GdkCursor* castitem, bool make_a_copy)
{
  // For BoxedType wrappers, make_a_copy is true by default.  The static
  // BoxedType wrappers must always take a copy, thus make_a_copy = true
  // ensures identical behaviour if the default argument is used.

  if(make_a_copy)
  {
    if(castitem)
      gobject_ = gdk_cursor_ref(castitem);
    else
      gobject_ = 0;
  }
  else
  {
    // It was given to us by a function which has already made a copy for us to keep.
    gobject_ = castitem;
  }
}

Cursor& Cursor::operator=(const Cursor& src)
{
  GdkCursor *const new_gobject = (src.gobject_) ? gdk_cursor_ref(src.gobject_) : 0;

  if(gobject_)
    gdk_cursor_unref(gobject_);
  gobject_ = new_gobject;

  return *this;
}

Cursor::~Cursor()
{
  if(gobject_)
    gdk_cursor_unref(gobject_);}


GdkCursor* Cursor::gobj_copy() const
{
  return gdk_cursor_ref(gobject_);
}


} // namespace Gdk
